==> mastercard_mc_on-1.0.0-py2-none-any.whl: mastercardmcon/insurance.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmcon import ResourceConfig

class Insurance(BaseObject):
    """
    
    """

    __config = {
        
        "c8c16ef5-0bc2-45ce-99e9-b1ecd4056146" : OperationConfig("/loyalty/v1/insurance/claim", "create", ["x-client-correlation-id"], []),
        
        "ed9f23e7-9a31-48e7-a7c5-1f062a620fba" : OperationConfig("/loyalty/v1/insurance/tokenizeUserData", "create", ["x-client-correlation-id"], []),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())


    @classmethod
    def getInsuranceClaim(cls,mapObj):
        """
        Creates object of type Insurance

        @param Dict mapObj, containing the required parameters to create a new object
        @return Insurance of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("c8c16ef5-0bc2-45ce-99e9-b1ecd4056146", Insurance(mapObj))






    @classmethod
    def tokenizeUserData(cls,mapObj):
        """
        Creates object of type Insurance

        @param Dict mapObj, containing the required parameters to create a new object
        @return Insurance of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("ed9f23e7-9a31-48e7-a7c5-1f062a620fba", Insurance(mapObj))

==> mastercard_mc_on-1.0.1-py2-none-any.whl: mastercardmcon/insurance.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardmcon import ResourceConfig

class Insurance(BaseObject):
    """
    
    """

    __config = {
        
        "7ba1e6da-fcea-4187-96a0-26fdad3c03b1" : OperationConfig("/loyalty/v1/insurance/claim", "create", ["x-client-correlation-id"], []),
        
        "45a2137a-7e2f-4bd1-9f09-f8fafe905c61" : OperationConfig("/loyalty/v1/insurance/tokenizeUserData", "create", ["x-client-correlation-id"], []),
        
    }

    def getOperationConfig(self,operationUUID):
        if operationUUID not in self.__config:
            raise Exception("Invalid operationUUID: "+operationUUID)

        return self.__config[operationUUID]

    def getOperationMetadata(self):
        return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())


    @classmethod
    def getInsuranceClaim(cls,mapObj):
        """
        Creates object of type Insurance

        @param Dict mapObj, containing the required parameters to create a new object
        @return Insurance of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("7ba1e6da-fcea-4187-96a0-26fdad3c03b1", Insurance(mapObj))






    @classmethod
    def tokenizeUserData(cls,mapObj):
        """
        Creates object of type Insurance

        @param Dict mapObj, containing the required parameters to create a new object
        @return Insurance of the response of created instance.
        @raise ApiException: raised an exception from the response status
        """
        return BaseObject.execute("45a2137a-7e2f-4bd1-9f09-f8fafe905c61", Insurance(mapObj))
